/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

import anthill.util.*;
import java.io.*;

/**
 *
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface Gate
extends Clearable
{
  
  /**
   *  Returns the identifier of the Anthill to which this
   *  gate is associated.
   *
   */
  public AnthillId getId();

  
  /**
   *  Set the agent listener, i.e. the object that will
   *  accept the agents coming from other anthills.
   *
   *  @param listener the listener object that will
   *    accepts the agents coming from other anthills
   */
  public void setAntListener(AntListener listener);
  
  
  /**
   *  Send an agent to the specified anthill. Both the anthill
   *  identifier and the agent must be serializable or
   *  externalizable.
   *
   * @exception ClassCastException
   *   raised if the anthill identifier does not belong to the
   *   expected class
   * @exception IOException
   *   raised if something goes wrong during serialization
   *   and sending
   */
  public void send(AnthillId id, Ant agent)
    throws IOException, ClassCastException;
  
} // END Gate
