/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

import anthill.*;
import anthill.util.*;

/**
 *  The <CODE>QuerySet</CODE> interface represents a database which maintains 
 *  associations between query strings and the query listener that has 
 *  to be notified when the query is satisfied.
 * 
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface QuerySet
extends Clearable
{

  /**
   *  Maps the specified query to the associated listener object.
   *
   *  @param query the string query to be performed
   *  @param listener the listener which will be notified when
   *    the query is completed
   */
  public void add(String query, QueryListener listener);
  
 
  /**
   *  This method is used to notify the fact that the given
   *  query has returned the specified set of resources.
   * 
   *  @param query      the completed query
   *  @param resources  the resources found.
   */
  public void returnResources(String query, Resource[] resources);
  
} // END QuerySet
