/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.genie;

import anthill.*;
import anthill.gf.*;
import anthill.util.Printable;


/**
 *  Interface PeernetFactory is the interface for creating 
 *  Peernet objects.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class PeernetFactoryImpl
extends Printable
implements PeernetFactory
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Anthill factory */
  AnthillFactory anthillf;

  /** Number of nodes of the network */
  int size;
  
  /** Degree of the network */
  int degree;
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Initialize a new Peernet anthillf
   */
  public PeernetFactoryImpl(AnthillFactory anthillf, int size, int degree)
  {
    this.anthillf = anthillf;
    this.size = size;
    this.degree = degree;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from PeernetFactory
  ////////////////////////////////////////////////////////////////////////////////////////////
 
  /**
   *  Return a Scenario for evaluating the fitness of a genetic code
   */
  public Peernet getPeernet()
  {
    return new PeernetImpl(this);
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // "getter" methods for fields (package visibility)
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Return the anthill factory included in this object
   */
  final AnthillFactory getAnthillFactory()
  {
    return anthillf;
  }

  /**
   *  Return the size of the network (number of nodes)
   */
  final int getSize()
  {
    return size;
  }
  
  /**
   *  Return the degree of the network (number of arcs per node)
   */
  final int getDegree()
  {
    return degree;
  }

  
} // END PeernetFactoryImpl

