/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.genie;

import anthill.*;
import anthill.gf.*;
import anthill.util.Printable;

/**
 *  Simple implementation of the ScenarioFactory interface.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class ScenarioFactoryImpl
extends Printable
implements ScenarioFactory
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /** Peernet factory used to generate the P2P network */
  private PeernetFactory peernetf;

  /** Resource factory used to generate resource to be put int the network */
  private ResourceFactory resourcef;

  /** Number of iterations to be performed */
  private int iterations;
  
  /** Number of resources to be stored in the peernet */
  private int nresources;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Constructs a new scenario factory
   */
  public ScenarioFactoryImpl(PeernetFactory peernetf, ResourceFactory resourcef, 
    int iterations, int nresources)
  {
    this.peernetf = peernetf;
    this.resourcef = resourcef;
    this.iterations = iterations;
    this.nresources = nresources;
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from ScenarioFactory
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Return a ScenarioImpl for evaluating the fitness of a genetic code
   */
  public Scenario getScenario()
  {
    return new ScenarioImpl(this);
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // "getter" methods for fields (package visibility)
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Return the peernet factory parameter
   */
  final PeernetFactory getPeernetFactory()
  {
    return peernetf;
  }
  
  /**
   *  Return the peernet factory parameter
   */
  final ResourceFactory getResourceFactory()
  {
    return resourcef;
  }

  /**
   *  Return the number of iterations
   */
  final int getIterations()
  {
    return iterations;
  }
  
  /**
   *  Return the number of number of resources to be created
   */
  final int getNresources()
  {
    return nresources;
  }  
  
} // END ScenarioFactoryImpl

