/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import java.util.*;
import anthill.*;

/**
 *  This class is a database which maintains associations between
 *  a query string and the query listener that is to be notified
 *  when the query is satisfied.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class LocalQuerySet
implements QuerySet
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Map that associates listeners to query strings */
  HashMap map;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  
   */
  public LocalQuerySet()
  {
    init(true);
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods 
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Maps the specified query to the associated listener object.
   *
   *  @param query the string query to be performed
   *  @param listener the listener which will be notified when
   *    the query is completed
   */
  public void add(String query, QueryListener listener)
  {
    map.put(query, listener);
  }
  
 
  /**
   *  Return 
   */
  public void returnResources(String query, Resource[] resources)
  {
    QueryListener listener = (QueryListener) map.get(query);
    if (listener != null) {
      listener.returnResources(resources);
    }
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Clearable
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Restore the object to its initial state.
   */
  public void clear()
  {
    init(false);
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Private methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Initialize the object
   *
   *  @param constructor true if the method is invoked by the
   *    constructor
   */
  private void init(boolean constructor)
  {
    if (constructor) {
      map = new HashMap();
    } else {
      map.clear();
    }
  }
  
} // END LocalQuerySet
